import { LitElement } from 'lit';
declare global {
    interface Prism {
        languages: Record<string, Prism.Grammar>;
    }
}
import 'prismjs';
/**
 * Render code in a styled and formatted way. `<pfe-codeblock>` highlights code snippets on the page.
 *
 * @summary Render code in a styled and formatted way.
 *
 * @csspart pre - The `<pre>` container for the codeblock
 * @csspart code - The `<code>` element containing the rendered codeblock
 */
export declare class PfeCodeblock extends LitElement {
    static readonly version = "{{version}}";
    static readonly styles: import("lit").CSSResult[];
    /**
     * Specify a code language for display. Possible values are:
     * - `markup` (default)
     * - `html`
     * - `xml`
     * - `svg`
     * - `mathml`
     * - `css`
     * - `clike`
     * - `javascript`
     * - `js`
   */
    codeLanguage: 'markup' | 'html' | 'xml' | 'svg' | 'mathml' | 'css' | 'clike' | 'javascript' | 'js';
    /** Optional boolean attribute that, when present, shows line numbers in the code block. */
    codeLineNumbers: boolean;
    /**
     * Set the theme of the code block. Possible values are:
     * - `light` (default)
     * - `dark`
     */
    codeTheme: 'dark' | 'light';
    /** Set the line number start value */
    codeLineNumberStart: number;
    /** String code source. Set to render the provided block */
    codeblock: string;
    private renderedCodeBlock;
    /** prism.js language css class for the snippet */
    private get prismClassName();
    /** prism.js grammar for the snippet */
    private get grammar();
    private _codeblockContainer;
    private _observer;
    connectedCallback(): void;
    render(): import("lit-html").TemplateResult<1>;
    disconnectedCallback(): void;
    protected _codeblockChanged(_: string, text: string): void;
    /** Accepts string and Returns trimed string and new line count */
    private trimWhitespaceLines;
    private processLineNumbers;
    private updateCodeBlock;
}
declare global {
    interface HTMLElementTagNameMap {
        'pfe-codeblock': PfeCodeblock;
    }
}
